@@ -4,8 +4,10 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import List, Optional, Type
 
-from dataclasses_json import dataclass_json
 from metaphor.models.metadata_change_event import MetadataChangeEvent
+from serde import deserialize
+from serde.json import from_json
+from serde.yaml import from_yaml
 from smart_open import open
 
 from .api_sink import ApiSink, ApiSinkConfig
@@ -15,7 +17,7 @@ logger = logging.getLogger()
 logger.setLevel(logging.INFO)
 
 
-@dataclass_json
+@deserialize
 @dataclass
 class OutputConfig:
     """Config for where to output the data"""
@@ -24,12 +26,12 @@ class OutputConfig:
     file: Optional[FileSinkConfig] = None
 
 
-@dataclass_json
+@deserialize
 @dataclass
 class RunConfig:
     """Base class for runtime parameters
 
-    All subclasses should add the @dataclass_json & @dataclass decorators
+    All subclasses should add the @dataclass @deserialize decorators
     """
 
     output: OutputConfig
@@ -37,8 +39,12 @@ class RunConfig:
     @classmethod
     def from_json_file(cls, path: str) -> "RunConfig":
         with open(path, encoding="utf8") as fin:
-            # Ignored due to https://github.com/lidatong/dataclasses-json/issues/23
-            return cls.from_json(fin.read())  # type: ignore
+            return from_json(cls, fin.read())
+
+    @classmethod
+    def from_yaml_file(cls, path: str) -> "RunConfig":
+        with open(path, encoding="utf8") as fin:
+            return from_yaml(cls, fin.read())
 
 
 class BaseExtractor(ABC):
@@ -49,7 +55,7 @@ class BaseExtractor(ABC):
     def config_class() -> Type[RunConfig]:
         """Returns the corresponding config class"""
 
-    def run(self, config: RunConfig) -> bool:
+    def run(self, config: RunConfig) -> List[MetadataChangeEvent]:
         """Callable function to extract metadata and send/post messages"""
         logger.info("Starting extractor {}".format(self.__class__.__name__))
 
@@ -57,16 +63,13 @@ class BaseExtractor(ABC):
 
         logger.info("Fetched {} entities".format(len(events)))
 
-        no_error = True
-
         if config.output.api is not None:
-            no_error = no_error & ApiSink(config.output.api).sink(events)
+            ApiSink(config.output.api).sink(events)
 
         if config.output.file is not None:
-            no_error = no_error & FileSink(config.output.file).sink(events)
+            FileSink(config.output.file).sink(events)
 
-        logger.info("Execution finished")
-        return no_error
+        return events
 
     @abstractmethod
     async def extract(self, config: RunConfig) -> List[MetadataChangeEvent]:
