@@ -3,8 +3,9 @@ import logging
 from abc import ABC, abstractmethod
 from typing import Generator, List
 
+from metaphor.models.metadata_change_event import MetadataChangeEvent
+
 from .event_util import EventUtil
-from .metadata_change_event import MetadataChangeEvent
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -13,8 +14,8 @@ logger.setLevel(logging.INFO)
 class Sink(ABC):
     """Base class for metadata sinks"""
 
-    def send_messages(self, events: List[MetadataChangeEvent]) -> bool:
-        """Send MCE messages to ingestion pipeline"""
+    def sink(self, events: List[MetadataChangeEvent]) -> bool:
+        """Sink MCE messages to the destination"""
         records = [EventUtil.trim_event(e) for e in events]
         valid_records = [r for r in records if EventUtil.validate_message(r)]
         logger.debug(f"Records: {json.dumps(valid_records)}")
@@ -31,4 +32,4 @@ class Sink(ABC):
 
     @abstractmethod
     def _sink(self, messages: List[dict]) -> bool:
-        """Sink metadata records to ingestion pipeline, should be overridden"""
+        """Sink metadata records to the destination, should be overridden"""
