@@ -24,6 +24,7 @@ class Connection:
     name: str
     platform: DataPlatform
     database: str
+    account: Optional[str]
     default_schema: Optional[str]
 
 
@@ -91,7 +92,9 @@ class Explore:
 
         return EntityId(
             EntityType.DATASET,
-            DatasetLogicalID(name=full_name, platform=connection.platform),
+            DatasetLogicalID(
+                name=full_name, platform=connection.platform, account=connection.account
+            ),
         )
 
     @staticmethod
